var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var F01409;
(function (F01409) {
    var FDocument = (function (_super) {
        __extends(FDocument, _super);
        function FDocument(id, version, oldVersion) {
            var _this = _super.call(this, id, version, oldVersion) || this;
            _this._p4DataTable = null;
            _this._p1TotalTable = null;
            _this._p4Sheet = null;
            _this._analyticSheet = null;
            _this._analyticsDataTable = null;
            _this._p5RefObjTable = null;
            _this._p5RefOkpdTable = null;
            _this._p5RefKosguTable = null;
            _this._p5RefObjDescTable = null;
            _this._p5RefObjDescNpaTable = null;
            _this._p5Sp1Sheet = null;
            _this._interfaceRules = new F01409.InterfaceRules(_this);
            _this._updateRules = new F01409.UpdateRules(_this);
            _this._exportRules = new F01409.ExportRules(_this);
            return _this;
        }
        Object.defineProperty(FDocument.prototype, "P4Sheet", {
            get: function () {
                if (this._p4Sheet == null) {
                    this._p4Sheet = new OnlyInsuranceSheet("SHT_F04_109_R4", this);
                }
                return this._p4Sheet;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(FDocument.prototype, "P1TotalTable", {
            get: function () {
                if (this._p1TotalTable == null) {
                    this._p1TotalTable = new F01409.ObasTableP1Total("F01_400_R1_Values", this);
                }
                return this._p1TotalTable;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(FDocument.prototype, "P4DataTable", {
            get: function () {
                if (this._p4DataTable == null) {
                    this._p4DataTable = new F01409.P4DataObasTable("F01_409_R4_Data", this, this.P1TotalTable, F01409.StrKeysP1.P4);
                }
                return this._p4DataTable;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(FDocument.prototype, "AnalyticSheet", {
            get: function () {
                if (this._analyticSheet == null) {
                    this._analyticSheet = new F01409.AnalyticSheet("SHT_RA", this);
                }
                return this._analyticSheet;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(FDocument.prototype, "AnalyticsDataTable", {
            get: function () {
                if (this._analyticsDataTable == null) {
                    this._analyticsDataTable = new AnalyticsKosgu.AnalyticsDataTable("Analytics_Values", this);
                }
                return this._analyticsDataTable;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(FDocument.prototype, "PurchaseObjectsSprTable", {
            get: function () {
                if (this._purchaseObjectsSprTable == null) {
                    this._purchaseObjectsSprTable = new F01XXXBase.PurchaseObjectsSprTable();
                }
                return this._purchaseObjectsSprTable;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(FDocument.prototype, "P5RefObjTable", {
            get: function () {
                if (this._p5RefObjTable == null) {
                    this._p5RefObjTable = new F01XXXBase.PartObjectDataTable("F01_409_R5_Ref_Object", this, this.P5RefObjDescTable);
                }
                return this._p5RefObjTable;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(FDocument.prototype, "P5RefOkpdTable", {
            get: function () {
                if (this._p5RefOkpdTable == null) {
                    this._p5RefOkpdTable = new F01XXXBase.PartOkpdTable("F01_409_R5_Ref_Okpd", this, this.P5RefObjTable);
                }
                return this._p5RefOkpdTable;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(FDocument.prototype, "P5RefKosguTable", {
            get: function () {
                if (this._p5RefKosguTable == null) {
                    this._p5RefKosguTable = new F01XXXBase.PartKosguTable("F01_409_R5_Ref_Kosgu", this, this.P5RefOkpdTable);
                }
                return this._p5RefKosguTable;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(FDocument.prototype, "P5RefObjDescTable", {
            get: function () {
                if (this._p5RefObjDescTable == null) {
                    this._p5RefObjDescTable = new F01XXXBase.ObjectDescTable("F01_409_R5_Ref_ObjectDesc", this);
                }
                return this._p5RefObjDescTable;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(FDocument.prototype, "P5RefObjDescNpaTable", {
            get: function () {
                if (this._p5RefObjDescNpaTable == null) {
                    this._p5RefObjDescNpaTable = new F01XXXBase.ObjectDescNpaTable("F01_409_R5_Ref_Npa", this, this.P5RefObjDescTable);
                }
                return this._p5RefObjDescNpaTable;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(FDocument.prototype, "P5Sp1Sheet", {
            get: function () {
                if (this._p5Sp1Sheet == null) {
                    this._p5Sp1Sheet = new F01XXXBase.PurchaseObjectHierarchySheet(this);
                }
                return this._p5Sp1Sheet;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(FDocument.prototype, "InterfaceRules", {
            get: function () {
                return this._interfaceRules;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(FDocument.prototype, "UpdateRules", {
            get: function () {
                return this._updateRules;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(FDocument.prototype, "ExportRules", {
            get: function () {
                return this._exportRules;
            },
            enumerable: true,
            configurable: true
        });
        return FDocument;
    }(F01400.FDocument));
    F01409.FDocument = FDocument;
})(F01409 || (F01409 = {}));
